Module core

Module core 

Modules

genomic_interpretation
Nested message and enum types in GenomicInterpretation.
interpretation
Nested message and enum types in Interpretation.
measurement
Nested message and enum types in Measurement.
medical_action
Nested message and enum types in MedicalAction.
pedigree
Nested message and enum types in Pedigree.
therapeutic_regimen
Nested message and enum types in TherapeuticRegimen.
time_element
Nested message and enum types in TimeElement.
value
Nested message and enum types in Value.
vital_status
Nested message and enum types in VitalStatus.

Structs

Age
See http://build.fhir.org/datatypes and http://build.fhir.org/condition-definitions.html#Condition.onset_x_ In FHIR this is represented as a UCUM measurement - http://unitsofmeasure.org/trac/
AgeRange
Biosample
A Biosample refers to a unit of biological material from which the substrate molecules (e.g. genomic DNA, RNA, proteins) for molecular analyses (e.g. sequencing, array hybridisation, mass-spectrometry) are extracted. Examples would be a tissue biopsy, a single cell from a culture for single cell genome sequencing or a protein fraction from a gradient centrifugation. Several instances (e.g. technical replicates) or types of experiments (e.g. genomic array as well as RNA-seq experiments) may refer to the same Biosample. FHIR mapping: Specimen (http://www.hl7.org/fhir/specimen.html).
ComplexValue
Diagnosis
Disease
Message to indicate a disease (diagnosis) and its recorded onset.
DoseInterval
e.g. 50mg/ml 3 times daily for two weeks
Evidence
FHIR mapping: Condition.evidence (https://www.hl7.org/fhir/condition-definitions.html#Condition.evidence)
ExternalReference
FHIR mapping: Reference (https://www.hl7.org/fhir/references.html)
File
GenomicInterpretation
A statement about the contribution of a genomic element towards the observed phenotype. Note that this does not intend to encode any knowledge or results of specific computations.
GestationalAge
Individual
An individual (or subject) typically corresponds to an individual human or another organism. FHIR mapping: Patient (https://www.hl7.org/fhir/patient.html).
Interpretation
Measurement
FHIR mapping: Observation (https://www.hl7.org/fhir/observation.html)
MedicalAction
medication, procedure, other actions taken for clinical management
MetaData
OntologyClass
A class (aka term, concept) in an ontology. FHIR mapping: CodeableConcept (http://www.hl7.org/fhir/datatypes.html#CodeableConcept) see also Coding (http://www.hl7.org/fhir/datatypes.html#Coding)
Pedigree
https://software.broadinstitute.org/gatk/documentation/article?id=11016
PhenotypicFeature
An individual phenotypic feature, observed as either present or absent (negated), with possible onset, modifiers and frequency FHIR mapping: Condition (https://www.hl7.org/fhir/condition.html) or Observation (https://www.hl7.org/fhir/observation.html)
Procedure
A clinical procedure performed on a subject. By preference a single concept to indicate both the procedure and the body site should be used. In cases where this is not possible, the body site should be indicated using a separate ontology class. e.g. {“code”:{“NCIT:C51585”: “Biopsy of Soft Palate”}} {“code”:{“NCIT:C28743”: “Punch Biopsy”}, “body_site”:{“UBERON:0003403”: “skin of forearm”}} - a punch biopsy of the skin from the forearm FHIR mapping: Procedure (https://www.hl7.org/fhir/procedure.html)
Quantity
RadiationTherapy
RadiationTherapy
ReferenceRange
Resource
Description of an external resource used for referencing an object. For example the resource may be an ontology such as the HPO or SNOMED. FHIR mapping: CodeSystem (http://www.hl7.org/fhir/codesystem.html)
TherapeuticRegimen
TimeElement
TimeInterval
Treatment
treatment with an agent, such as a drug
TypedQuantity
For complex measurements, such as blood pressure where more than one component quantity is required to describe the measurement
Update
Information about when an update to a record occurred, who or what made the update and any pertinent information regarding the content and/or reason for the update
Value
VariantInterpretation
VitalStatus

Enums

AcmgPathogenicityClassification
DrugType
A simplified version of ODHSI-DRUG_EXPOSURE
KaryotypicSex
Karyotypic sex of the individual
Sex
Sex of an individual FHIR mapping: AdministrativeGender (https://www.hl7.org/fhir/codesystem-administrative-gender.html)
TherapeuticActionability