A Biosample refers to a unit of biological material from which the substrate
molecules (e.g. genomic DNA, RNA, proteins) for molecular analyses (e.g.
sequencing, array hybridisation, mass-spectrometry) are extracted. Examples
would be a tissue biopsy, a single cell from a culture for single cell genome
sequencing or a protein fraction from a gradient centrifugation.
Several instances (e.g. technical replicates) or types of experiments (e.g.
genomic array as well as RNA-seq experiments) may refer to the same Biosample.
FHIR mapping: Specimen (http://www.hl7.org/fhir/specimen.html).
A statement about the contribution of a genomic element towards the observed phenotype. Note that this does not intend
to encode any knowledge or results of specific computations.
An individual (or subject) typically corresponds to an individual human or another organism.
FHIR mapping: Patient (https://www.hl7.org/fhir/patient.html).
A clinical procedure performed on a subject. By preference a single concept to indicate both the procedure and the
body site should be used. In cases where this is not possible, the body site should be indicated using a separate
ontology class.
e.g.
{“code”:{“NCIT:C51585”: “Biopsy of Soft Palate”}}
{“code”:{“NCIT:C28743”: “Punch Biopsy”}, “body_site”:{“UBERON:0003403”: “skin of forearm”}} - a punch biopsy of the skin from the forearm
FHIR mapping: Procedure (https://www.hl7.org/fhir/procedure.html)
Description of an external resource used for referencing an object. For example the resource may be an ontology such
as the HPO or SNOMED.
FHIR mapping: CodeSystem (http://www.hl7.org/fhir/codesystem.html)
Information about when an update to a record occurred, who or what made the update and any pertinent information
regarding the content and/or reason for the update