pub struct GenomicInterpretation {
pub subject_or_biosample_id: String,
pub interpretation_status: i32,
pub call: Option<Call>,
}Expand description
A statement about the contribution of a genomic element towards the observed phenotype. Note that this does not intend to encode any knowledge or results of specific computations.
Fields
subject_or_biosample_id: Stringidentifier for the subject of the interpretation. This MUST be the individual id or a biosample id of the enclosing phenopacket.
interpretation_status: i32call: Option<Call>Gene or variant identified in subject or biosample and interpreted in relation to the disease diagnosis. In this context athe ‘gene’ is a proxy for an unspecified alteration in the indicated gene.
Implementations
Sourceimpl GenomicInterpretation
impl GenomicInterpretation
Sourcepub fn interpretation_status(&self) -> InterpretationStatus
pub fn interpretation_status(&self) -> InterpretationStatus
Returns the enum value of interpretation_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_interpretation_status(&mut self, value: InterpretationStatus)
pub fn set_interpretation_status(&mut self, value: InterpretationStatus)
Sets interpretation_status to the provided enum value.